==> concierge-2.0.0-sources.jar: com/flybits/concierge/fragments/OptInFragment.kt <==
package com.flybits.concierge.fragments

import android.arch.lifecycle.Observer
import android.arch.lifecycle.ViewModelProviders
import android.content.pm.ActivityInfo
import android.graphics.Typeface
import android.os.Bundle
import android.support.v4.app.Fragment
import android.text.Spannable
import android.text.SpannableStringBuilder
import android.text.style.StyleSpan
import android.text.style.UnderlineSpan
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import com.afollestad.materialdialogs.MaterialDialog
import com.flybits.concierge.FlybitsNavigator
import com.flybits.concierge.R
import com.flybits.concierge.viewmodels.OptInViewModel
import com.flybits.concierge.viewmodels.OptInViewModelFactory
import kotlinx.android.synthetic.main.flybits_con_fragment_opt_in.*

class OptInFragment: Fragment(){

    internal var viewModel: OptInViewModel? = null

    companion object {
        fun newInstance(): OptInFragment {
            return OptInFragment()
        }
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        return inflater.inflate(R.layout.flybits_con_fragment_opt_in, container, false)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        viewModel = ViewModelProviders.of(this, OptInViewModelFactory(context!!)).get(OptInViewModel::class.java)
        activity?.requestedOrientation = ActivityInfo.SCREEN_ORIENTATION_PORTRAIT
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        //Set the footer text
        viewModel?.footerSpan?.observe(this, Observer<OptInViewModel.Span> { span ->
            span?.let {
                val str = SpannableStringBuilder(it.text)
                str.setSpan(StyleSpan(Typeface.BOLD), it.startIndex, it.endIndex, Spannable.SPAN_EXCLUSIVE_EXCLUSIVE)
                str.setSpan(UnderlineSpan(), it.startIndex, it.endIndex, Spannable.SPAN_EXCLUSIVE_EXCLUSIVE)
                text_footer.text = str
            }
        })

        text_footer.setOnClickListener {
            (parentFragment as FlybitsNavigator).openFragment(
                    TermsAndServicesFragment.newInstance(true), addToBackStack = true)
        }

        checkbox_optin.setOnClickListener {
            viewModel?.checkboxSelected()
        }

        viewModel?.checkboxState?.observe(this, Observer<Boolean> {
            checkbox_optin.isSelected = it ?: false
            btn_continue.isEnabled = it ?: false
        })

        btn_continue.setOnClickListener {
            progress_bar?.visibility = View.VISIBLE
            viewModel?.optIn()?.observe(this, Observer<OptInViewModel.OptInResult> {
                if (it?.success == true) {
                    //Do nothing, concierge fragment will handle transition
                } else {
                    context?.let { contextNonNull ->
                        MaterialDialog.Builder(contextNonNull)
                                .title(R.string.flybits_con_error)
                                .content(getString(R.string.flybits_con_opt_in_error_message))
                                .positiveText(android.R.string.ok)
                                .show()
                    }
                }
                progress_bar?.visibility = View.GONE
            })
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        viewModel = null
        activity?.requestedOrientation = ActivityInfo.SCREEN_ORIENTATION_FULL_SENSOR
    }
}

==> concierge-2.6.0-sources.jar: com/flybits/concierge/fragments/OptInFragment.kt <==
package com.flybits.concierge.fragments

import android.arch.lifecycle.Observer
import android.arch.lifecycle.ViewModelProviders
import android.content.pm.ActivityInfo
import android.graphics.Typeface
import android.os.Bundle
import android.support.v4.app.Fragment
import android.text.Spannable
import android.text.SpannableStringBuilder
import android.text.style.StyleSpan
import android.text.style.UnderlineSpan
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import com.afollestad.materialdialogs.MaterialDialog
import com.flybits.concierge.ConciergeConfiguration
import com.flybits.concierge.FlybitsConcierge
import com.flybits.concierge.FlybitsNavigator
import com.flybits.concierge.R
import com.flybits.concierge.viewmodels.OptInViewModel
import com.flybits.concierge.viewmodels.OptInViewModelFactory
import kotlinx.android.synthetic.main.flybits_con_fragment_opt_in.*
import kotlinx.android.synthetic.main.flybits_con_fragment_opt_in.progress_bar
import kotlinx.android.synthetic.main.flybits_con_fragment_settings.*

class OptInFragment: Fragment(){

    internal var viewModel: OptInViewModel? = null

    companion object {
        fun newInstance(): OptInFragment {
            return OptInFragment()
        }
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        return inflater.inflate(R.layout.flybits_con_fragment_opt_in, container, false)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        viewModel = ViewModelProviders.of(this, OptInViewModelFactory(context!!)).get(OptInViewModel::class.java)
        activity?.requestedOrientation = ActivityInfo.SCREEN_ORIENTATION_PORTRAIT
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        opt_in_text_body.text =  viewModel?.optInText

        //Set the footer text
        viewModel?.footerSpan?.observe(this, Observer<OptInViewModel.Span> { span ->
            span?.let {
                val str = SpannableStringBuilder(it.text)
                str.setSpan(StyleSpan(Typeface.BOLD), it.startIndex, it.endIndex, Spannable.SPAN_EXCLUSIVE_EXCLUSIVE)
                str.setSpan(UnderlineSpan(), it.startIndex, it.endIndex, Spannable.SPAN_EXCLUSIVE_EXCLUSIVE)
                text_footer.text = str
            }
        })

        text_footer.setOnClickListener {
            (parentFragment as FlybitsNavigator).openFragment(
                    TermsAndServicesFragment.newInstance(true), addToBackStack = true)
        }

        checkbox_optin.setOnClickListener {
            viewModel?.checkboxSelected()
        }

        viewModel?.checkboxState?.observe(this, Observer<Boolean> {
            checkbox_optin.isSelected = it ?: false
            btn_continue.isEnabled = it ?: false
        })

        btn_continue.setOnClickListener {
            progress_bar?.visibility = View.VISIBLE
            viewModel?.optIn()?.observe(this, Observer<OptInViewModel.OptInResult> {
                if (it?.success == true) {
                    //Do nothing, concierge fragment will handle transition
                } else {
                    context?.let { contextNonNull ->
                        MaterialDialog.Builder(contextNonNull)
                                .title(R.string.flybits_con_error)
                                .content(getString(R.string.flybits_con_opt_in_error_message))
                                .positiveText(android.R.string.ok)
                                .show()
                    }
                }
                progress_bar?.visibility = View.GONE
            })
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        viewModel = null
        activity?.requestedOrientation = ActivityInfo.SCREEN_ORIENTATION_FULL_SENSOR
    }
}
